use Test::More tests => 2;

BEGIN {
use_ok( 'Acme::AsciiArt2HtmlTable' );
}

my $ex = '      ###   ######    ######  ########       #######   ######    ######  #######  #######    ######  
      ###  ########  #######  ########      ########  ########  #######  #######  ########  ######## 
      ##+  ##+  ###  +##      ##+           +##       ##+  ###  +##        ##+    ##+  ###  ##+  ### 
      +#+  +#+  #+#  +#+      +#+           +#+       +#+  #+#  +#+        +#+    +#+  #+#  +#+  #+# 
      ++#  #+#  +#+  ++##++   #+++.+        +#+       #+#+#+#+  ++##++     #++    #+#++#+   #+#  +#+ 
      +++  +#+  +++   ++#+++  +++++.        +++       +++#++++   ++#+++    +++    ++#+#+    +#+  +++ 
      ++.  ++.  +++      +.+  ++.           .++       ++.  +++      +.+    ++.    ++. .++   ++.  +++ 
 ++.  .+.  .+.  +.+      +.+  .+.           .+.       .+.  +.+      +.+    .+.    .+.  +.+  .+.  +.+ 
 ... . ..  ..... ..  .... ..   .. ....       ... ...  ..   ...  .... ..     ..    ..   ...  ..... .. 
  . ...     . .  .   .. . .   . .. ..        .. .. .   .   . .  .. . .      .      .   . .   . .  .  
';

my $res='<style>
.default td { height:1px; width:2px; }
.default tr {  }
</style>
<table class="default" border="0" cellpadding="0" cellspacing="0">
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ff0000"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
</tr>
<tr>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="00ff00"></td>
<td bgcolor="ffffff"></td>
<td bgcolor="ffffff"></td>
</tr>
</table>
';

is( aa2ht( { td=>{width=>"2px"},
                    colors=>{"#"=>"ffff00","+"=>"ff0000","."=>"00ff00"}
                  }, $ex ),
           $res );
